@@ -16,7 +16,7 @@
     <message>
         <location filename="../main.qml" line="86"/>
         <source>Cancel</source>
-        <translation>Zrušit</translation>
+        <translation>Storno</translation>
     </message>
 </context>
 </TS>
