@@ -21,12 +21,12 @@
 #define APPLICATION_H
 
 #include <QApplication>
-#include "audio/audiomanager.h"
 #include "theme/thememanager.h"
 #include "brightness/brightnessmanager.h"
 #include "battery/upowermanager.h"
 #include "language/language.h"
 #include "mouse/mousemanager.h"
+#include "touchpad/touchpadmanager.h"
 
 #include <QTimer>
 
@@ -37,20 +37,20 @@ class Application : public QApplication
 public:
     explicit Application(int &argc, char **argv);
 
-    AudioManager *audioManager() { return m_audioManager; }
-
     void invokeDesktopProcess();
-    void initKWin();
+    void initTrash();
+
+//    void initKWin();
 
 private:
-    AudioManager *m_audioManager;
     ThemeManager *m_themeManager;
     BrightnessManager *m_brightnessManager;
     UPowerManager *m_upowerManager;
     Language *m_language;
     Mouse *m_mouse;
+    TouchpadManager *m_touchpad;
 
-    QTimer *m_kwinTimer;
+//    QTimer *m_kwinTimer;
 };
 
 #endif // APPLICATION_H
